from __init__ import TextBox
import pygame
pygame.init()

WIDTH = 600
HEIGHT = 600
wn = pygame.display.set_mode((WIDTH, HEIGHT))


def redraw(box):
    wn.fill((255, 255, 255))

    box.draw(wn)

    pygame.display.update()


def main():
    run = True
    clock = pygame.time.Clock()

    box = TextBox(100, 100, 100, 100, prompt="username", fit_text_options="text")
    while run:
        clock.tick(60)
        redraw(box)

        # box.set_mouse(pygame.mouse.get_pos())

        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                pygame.quit()
                run = False
            if event.type == pygame.KEYDOWN:
                box.key_down(event)
            if event.type == pygame.MOUSEBUTTONDOWN:
                box.click(pygame.mouse.get_pos())
            # if event.type == pygame.MOUSEBUTTONUP:
            #     if box.picked_up:
            #         print(box.debug("pos")["data"])
            #     box.unclick()


main()



import pygame
pygame.init()

WIDTH = 600
HEIGHT = 600
wn = pygame.display.set_mode((WIDTH, HEIGHT))


def redraw():
    wn.fill((255, 255, 255))

    pygame.display.update()


def main():
    run = True
    clock = pygame.time.Clock()

    while run:
        clock.tick(60)
        redraw()

        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                pygame.quit()
                run = False


main()



from text_field_base import *


class Button(Base):
    def __init__(self, x, y, width, height, fit_text_options=None, base_colour=(255, 255, 255), message="", font_style="arial", font_size=None, font_colour=(0, 0, 0), bold=False, italics=False, antialias=True, alignment="left", border_width=2, border_colour=(0, 0, 0), top_left=0, top_right=0, bottom_left=0, bottom_right=0):
        super().__init__(x, y, width, height, fit_text_options, base_colour, message, font_style, font_size, font_colour, bold, italics, antialias, alignment, border_width, border_colour, top_left, top_right, bottom_left, bottom_right)

    def draw(self, wn):
        self._draw(wn)

    def click(self, mouse_pos):
        return self._select(mouse_pos)
